@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Access to the track.getInfo slice of the LastFM API
 
-our $VERSION = '0.0202';
+our $VERSION = '0.0203';
 
 use Moo;
 use strictures 2;
@@ -57,6 +57,7 @@ sub fetch {
 
     croak 'No artist provided' unless $args{artist};
     croak 'No track provided' if $self->method eq 'track.getInfo' && !$args{track};
+    croak 'No album provided' if $self->method eq 'album.getInfo' && !$args{album};
 
     my $url = Mojo::URL->new($self->base)
         ->path($self->version)
@@ -117,7 +118,7 @@ WebService::LastFM::TrackInfo - Access to the track.getInfo slice of the LastFM
 
 =head1 VERSION
 
-version 0.0202
+version 0.0203
 
 =head1 SYNOPSIS
 
@@ -149,7 +150,8 @@ Default: C<undef>
 
 =head2 method
 
-The required, last.fm API method string.
+The required, last.fm API method string ("track.getInfo",
+"artist.getInfo", or "album.getInfo").
 
 Default: C<track.getInfo>
 
@@ -193,6 +195,7 @@ required B<api_key> argument.
 =head2 fetch
 
   $r = $w->fetch(artist => $artist, track => $track);
+  $r = $w->fetch(artist => $artist, album => $album); # for method => album.getInfo
   $r = $w->fetch(artist => $artist); # for method => artist.getInfo
 
 Fetch the results given the B<artist> and B<track> arguments.
@@ -201,7 +204,7 @@ Fetch the results given the B<artist> and B<track> arguments.
 
 The F<t/*> tests
 
-The F<eg/*> program(s)
+The F<eg/*> programs
 
 L<https://www.last.fm/api/show/track.getInfo>
 
